#!/bin/sh
set -e

SOURCE_DIR=$(realpath $(dirname "${0}"))/mifosx

# Check prerequisites
lxc-ls | grep -q mariadb || $(realpath $(dirname "${0}"))/mariadb.sh
lxc-ls | grep -q postfix || $(realpath $(dirname "${0}"))/postfix.sh
service mariadb start

# Build Docker container
docker build -t mifosx ${SOURCE_DIR}
cp ${SOURCE_DIR}/etc/init.d/mifosx /etc/init.d/mifosx
rc-update -u

# Create databases
export MIFOSX_PWD=$(head -c 18 /dev/urandom | base64)
envsubst <${SOURCE_DIR}/createdb.sql | docker exec -i mariadb mysql

# Populate database
docker run --rm mifosx cat /tmp/mifospltaform-tenants-first-time-install.sql | docker exec -i mariadb mysql mifosplatform-tenants
envsubst <${SOURCE_DIR}/schemapwd.sql | docker exec -i mariadb mysql mifosplatform-tenants

# Configure Mifos X
mkdir -p /srv/mifosx/conf
envsubst <${SOURCE_DIR}/srv/mifosx/conf/context.xml >/srv/mifosx/conf/context.xml
cp ${SOURCE_DIR}/srv/mifosx/conf/server.xml /srv/mifosx/conf/server.xml

# Populate database
service mifosx start
echo `date` '- Waiting for database to be populated. This should take about a minute.'
until docker logs mifosx 2>&1 | grep -q 'Migrating schema `mifostenant-default` to version 5000'; do
    sleep 1
done
service mifosx stop
# Fix missing previous_run_status column
echo 'ALTER TABLE `scheduled_email_campaign` ADD `previous_run_status` VARCHAR(10) NULL;' | docker exec -i mariadb mysql mifostenant-default

# Update admin account
export MIFOSX_ADMIN_USER=admin
export MIFOSX_ADMIN_EMAIL=admin@example.com
export MIFOSX_ADMIN_PWD=$(head -c 12 /dev/urandom | base64 | tr -d "+")
export MIFOSX_ADMIN_HASH=$(echo -n "${MIFOSX_ADMIN_PWD}{1}" | sha256sum | awk '{print $1}')
envsubst <${SOURCE_DIR}/adminpwd.sql | docker exec -i mariadb mysql mifostenant-default
vmmgr update-login mifosx "${MIFOSX_ADMIN_USER}" "${MIFOSX_ADMIN_PWD}"

# Stop services required for build
service mariadb stop
service postfix stop
